@@ -7,7 +7,7 @@ etc., the objects in the `BadgeKit REST API
 much of the network communication as possible, while not including a lot of
 special data about the structure of the API methods.  So, you will still need
 to know which methods can be called on which API endpoints, etc.
-At this point, a list of those endpoints `exists here
+**At this point, a list of available API endpoints** `exists here
 <https://github.com/mozilla/badgekit-api/blob/update-docs/docs/api-endpoints.md>`_.
 
 As an example of translating between that list and this client, the list
@@ -30,9 +30,11 @@ URL is constructed.
 Note that these classes are listed as being part of :mod:`badgekit.api`, but you
 can import them straight from :mod:`badgekit`.
 """
+
+
 import requests
 import posixpath
-from . import jwt_auth
+import requests_jwt
 from distutils.version import StrictVersion
 try:
     from urlparse import urljoin
@@ -51,6 +53,7 @@ __all__ = [
         'APIError',
         'ResourceNotFound',
         'ResourceConflict',
+        'ValidationError',
         ]
 
 
@@ -81,10 +84,18 @@ class ResourceNotFound(CodedBadgeKitException):
 class ResourceConflict(CodedBadgeKitException):
     "Thrown when POSTing an item that already exists"
 
+class ValidationError(CodedBadgeKitException):
+    "Thrown when creating an item with improper or missing fields"
+
+    def __str__(self):
+        super_str = super(ValidationError, self).__str__()
+        bad_fields = ", ".join([det['field'] for det in self.info.get('details', [])])
+        return ": ".join([super_str, bad_fields])
 
 errors = {
         'ResourceNotFound': ResourceNotFound,
         'ResourceConflict': ResourceConflict,
+        'ValidationError': ValidationError,
         }
 
 def raise_error(resp_obj, request):
@@ -97,8 +108,8 @@ def raise_error(resp_obj, request):
         resp_obj['code']
     except:
         raise APIError(
-                "Problem with %s %s, and Badgekit-API didn't return a comprehensible error." \
-                        % (request.method, request.url))
+                "Problem with %s %s: %s"
+                        % (request.method, request.url, repr(resp_obj)))
 
     raise exc_type(resp_obj, request)
 
@@ -174,23 +185,36 @@ class BadgeKitAPI(object):
     :param baseurl: the URL of the badgekit-api server.
     :param secret: the client secret.
     :param key: the name of the client secret, for the server to see.
+    :param defaults: a dict of default arguments, which can be overridden by actual arguments to the functions.
 
     For the moment, the secret is just the same secret that is used between
     the two Node.js servers, badgekit-api and openbadges-badgekit.  Look
     for it in the environment variables of the badgekit-api server - maybe
     a file called `.env`.
+
+    The ``defaults`` argument can be quite useful.  If your code will only have
+    to work with one badge system at a time - the badge system is in a configuration
+    file, for instance - then you can set it once and then not have to pass extra
+    info around to all your code that uses the api:
+
+    >>> bk = BadgeKitAPI('http://api.example.com/', 'secr3t', defaults={'system': 'mysystem'})
     """
-    def __init__(self, baseurl, secret, key='master'):
+    def __init__(self, baseurl, secret, key='master', defaults=None):
         self.baseurl = baseurl
 
-        auth = jwt_auth.JWTAuth(secret)
+        auth = requests_jwt.JWTAuth(secret)
         auth.add_field('key', key)
         auth.expire(30)
-        auth.add_field('path', jwt_auth.payload_path)
-        auth.add_field('method', jwt_auth.payload_method)
-        auth.add_field('body', jwt_auth.payload_body)
+        auth.add_field('path', requests_jwt.payload_path)
+        auth.add_field('method', requests_jwt.payload_method)
+        auth.add_field('body', requests_jwt.payload_body)
         self.auth = auth
 
+        if defaults:
+            self.defaults = dict(defaults)
+        else:
+            self.defaults = {}
+
     def ping(self):
         """Tests the server's availability - returns True if
         server is available, False otherwise."""
@@ -218,7 +242,8 @@ class BadgeKitAPI(object):
         for example, the above code would hit ``/systems/mysystem/badges``.
         """
         kind_plural = _api_plural(kind)
-        path = _make_path(kind_plural, **kwargs)
+        path_args = dict(self.defaults, **kwargs)
+        path = _make_path(kind_plural, **path_args)
         resp = requests.get(urljoin(self.baseurl, path), auth=self.auth)
         resp_obj = self._json_loads(resp.text)
         if resp.status_code != 200:
@@ -239,7 +264,8 @@ class BadgeKitAPI(object):
         object, and you just want to get that one object - for example, the
         above code would hit ``/systems/mysystem/badges/stupendous-badge``.
         """
-        path = _make_path(**kwargs)
+        path_args = dict(self.defaults, **kwargs)
+        path = _make_path(**path_args)
         resp = requests.get(urljoin(self.baseurl, path), auth=self.auth)
         resp_obj = self._json_loads(resp.text)
 
@@ -264,7 +290,8 @@ class BadgeKitAPI(object):
         For instance, the above code would post to ``/systems/mysystem/badges`` with
         ``data`` as the body of the request.
         """
-        path = _make_path(_api_plural(kind), **kwargs)
+        path_args = dict(self.defaults, **kwargs)
+        path = _make_path(_api_plural(kind), **path_args)
         resp = requests.post(urljoin(self.baseurl, path),
                 data=data,
                 auth=self.auth)
